Module drawing

Module drawing 

Drawing algorithms for consoles that don’t provide native rendering primitives.

Functions

bucket_fill
Fills the 4-connected region around xy via rasops.
draw_circle
Draws a circle via rasops with center and radius.
draw_circle_filled
Draws a circle via rasops with center and radius.
draw_line
Draws a line from x1y1 to x2y2 via rasops.
draw_poly
Draws a polygon via rasops.
draw_poly_filled
Draws a filled polygon via rasops.
draw_rect
Draws a rectangle via rasops starting at x1y1 with size.
draw_text
Writes a single character ch at pos.
draw_tri
Draws a triangle via rasops.
draw_tri_filled
Draws a filled triangle via rasops.