pub enum Resolution {
FullScreenDesktop,
FullScreen((NonZeroU32, NonZeroU32)),
Windowed((NonZeroU32, NonZeroU32)),
}Expand description
Representation of a screen resolution in pixels.
Variants
FullScreenDesktop
Tells the console to start in full screen mode at the current desktop resolution.
FullScreen((NonZeroU32, NonZeroU32))
Tells the console to start in full screen mode at the given resolution.
Windowed((NonZeroU32, NonZeroU32))
Tells the console to start in windowed mode at the given resolution.