pub fn rgb_to_ansi_color(rgb: RGB) -> Option<u8>Expand description
Converts an RGB color to an ANSI color number if there is an exact match.
This function does a linear scan of the known colors table and, as such, should not be used in performance-critical places.