pub trait ClampedMul<T, O> {
// Required method
fn clamped_mul(self, rhs: T) -> O;
}Expand description
Multiplication of values into a narrower type with silent value clamping.
Required Methods
Sourcefn clamped_mul(self, rhs: T) -> O
fn clamped_mul(self, rhs: T) -> O
Multiplies self by rhs and clamps the result to fit in O.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".