Module data

Module data 

Commands to interact with the data provided by DATA statements.

Structs

ReadCommand
The READ command.
RestoreCommand
The RESTORE command.

Functions

add_all
Instantiates all symbols in this module and adds them to the machine.