pub fn add_all(machine: &mut MachineBuilder)Expand description
Instantiates all symbols in this module and adds them to the machine.
pub fn add_all(machine: &mut MachineBuilder)Instantiates all symbols in this module and adds them to the machine.