pub fn add_all(machine: &mut MachineBuilder, datetime: Rc<dyn DateTime>)Expand description
Adds all symbols provided by this module to the given machine.
datetime provides access to date and time functionality.
pub fn add_all(machine: &mut MachineBuilder, datetime: Rc<dyn DateTime>)Adds all symbols provided by this module to the given machine.
datetime provides access to date and time functionality.