Module exec

Module exec 

Commands that manipulate the machine’s state or the program’s execution.

Structs

ClearCommand
The CLEAR command.
ErrmsgFunction
The ERRMSG function.

Functions

add_interactive
Instantiates all REPL commands for the interactive machine and adds them to the machine.
add_scripting
Instantiates all REPL commands for the scripting machine and adds them to the machine.