pub fn add_interactive(machine: &mut MachineBuilder)Expand description
Instantiates all REPL commands for the interactive machine and adds them to the machine.
pub fn add_interactive(machine: &mut MachineBuilder)Instantiates all REPL commands for the interactive machine and adds them to the machine.