pub fn add_scripting(machine: &mut MachineBuilder)Expand description
Instantiates all REPL commands for the scripting machine and adds them to the machine.
pub fn add_scripting(machine: &mut MachineBuilder)Instantiates all REPL commands for the scripting machine and adds them to the machine.