pub fn add_all(machine: &mut MachineBuilder, console: Rc<RefCell<dyn Console>>)Expand description
Adds all console-related commands for the given console to the machine.
pub fn add_all(machine: &mut MachineBuilder, console: Rc<RefCell<dyn Console>>)Adds all console-related commands for the given console to the machine.