Module lcd

Module lcd 

Generic types to represent and manipulate LCDs.

Modules

fonts
Support for bitmap fonts directly rendered onto an LCD.

Structs

BufferedLcd
Implements buffering for a backing slow LCD L that renders text with the font F.
LcdSize
Represents a size that fits in the LCD space.
LcdXY
Represents valid coordinates within the LCD space.
RGB565Pixel
Data for one pixel encoded as RGB565.

Traits

AsByteSlice
Trait to convert a pixel to a sequence of bytes.
Lcd
Primitives that an LCD must define.

Functions

to_xy_size
Converts a pair of coordinates to a top-left origin coordinate plus a size.