pub fn add_all(machine: &mut MachineBuilder, pins: Rc<RefCell<dyn Pins>>)Expand description
Adds all symbols provided by this module to the given machine.
pub fn add_all(machine: &mut MachineBuilder, pins: Rc<RefCell<dyn Pins>>)Adds all symbols provided by this module to the given machine.