pub fn add_all(machine: &mut MachineBuilder, console: Rc<RefCell<dyn Console>>)Expand description
Adds all help-related commands to the machine and makes them write to console.
pub fn add_all(machine: &mut MachineBuilder, console: Rc<RefCell<dyn Console>>)Adds all help-related commands to the machine and makes them write to console.