Module numerics

Module numerics 

Numerical functions for EndBASIC.

Structs

AbsFunction
The ABS function.
AcosFunction
The ACOS function.
AsinFunction
The ASIN function.
AtnFunction
The ATN function.
CintFunction
The CINT function.
CosFunction
The COS function.
DegCommand
The DEG command.
ExpFunction
The EXP function.
FixFunction
The FIX function.
IntFunction
The INT function.
LogFunction
The LOG function.
MaxFunction
The MAX function.
MinFunction
The MIN function.
PiFunction
The PI function.
Prng
Tracks the state of the PRNG used by the random number manipulation functions and commands.
RadCommand
The RAD command.
RandomizeCommand
The RANDOMIZE command.
RndFunction
The RND function.
RoundFunction
The ROUND function.
SgnFunction
The SGN function.
SinFunction
The SIN function.
SqrFunction
The SQR function.
TanFunction
The TAN function.

Enums

AngleMode
Indicates the calculation mode for trigonometric functions.

Functions

add_all
Adds all symbols provided by this module to the given machine.
double_to_integer
Converts the double d to an integer and fails if the conversion is not possible.