pub fn check_expr_ok<V: Into<ConstantDatum>>(exp_value: V, expr: &str)Expand description
Executes expr on a scripting interpreter and ensures that the result is exp_value.
pub fn check_expr_ok<V: Into<ConstantDatum>>(exp_value: V, expr: &str)Executes expr on a scripting interpreter and ensures that the result is exp_value.