TesterContinuation

Struct TesterContinuation 

pub struct TesterContinuation<'a> { /* private fields */ }
A tester that allows continuing a previous check.

This differs from Tester in that it provides direct access to the machine, because the machine has already been built at this point.

Implementations

Source

impl<'a> TesterContinuation<'a>

pub fn get_machine(&mut self) -> &mut Machine

Returns a mutable reference to the machine inside this continuation.

pub fn run<S: Into<String>>(self, script: S) -> Checker<'a>

Runs script in the configured machine and returns a Checker object to validate expectations about the execution.

pub fn clear(self) -> Self

Clears the state of the machine.