The EndBASIC standard library.
Modules
- arrays
- Array-related functions for EndBASIC.
- console
- Console representation and manipulation.
- data
- Commands to interact with the data provided by
DATAstatements. - exec
- Commands that manipulate the machine’s state or the program’s execution.
- gfx
- Commands for graphical console interaction.
- gpio
- GPIO access functions and commands for EndBASIC.
- help
- Interactive help support.
- numerics
- Numerical functions for EndBASIC.
- program
- Stored program manipulation.
- spi
- SPI bus abstractions for EndBASIC.
- storage
- Storage-related abstractions and commands.
- strings
- String functions for EndBASIC.
- testutils
- Test utilities for consumers of the EndBASIC interpreter.
Structs
- Interactive
Machine Builder - Builder pattern to construct an interpreter for REPL operation.
- Machine
- Executes an EndBASIC program and tracks its state.
- Machine
Builder - Builder pattern to construct an EndBASIC interpreter.
Enums
- Error
- Error types for callable execution.
- Machine
Action - Actions that callables can request the Machine to perform after an upcall returns.
- Signal
- Signals that can be delivered to the machine.
Traits
- Clearable
- Trait for objects that maintain state that can be reset to defaults.
- Yielder
- Trait to decide when the machine should cooperatively yield to the host.
Type Aliases
- Result
- Result type for callable execution.