MachineAction

Enum MachineAction 

pub enum MachineAction {
    Clear,
    Run(String),
}
Actions that callables can request the Machine to perform after an upcall returns.

Because callables don’t have direct access to the Machine, they push requests onto an action queue. The Machine’s exec loop drains this queue after each upcall, performing any requested side effects before resuming execution.

Variants



Clear

Reset all runtime state (variables, heap, clearables, last error).



Run(String)

Switches execution to the given program.