pub struct BufferedLcd<L: Lcd> { /* private fields */ }Expand description
Implements buffering for a backing slow LCD L that renders text with the font F.
All drawing operations are saved to a memory-backed framebuffer. If syncing is enabled, drawing primitives are flushed right away to the device; otherwise, they are applied to memory only until an explicit sync is requested. The framebuffer is also used to implement all pixel data reading.
Implementations